lookup

Function lookup 

pub fn lookup(qtype: &str) -> Option<TypeDef>
Look up a (canonicalized) question type. Select types are handled by the parser before reaching here, because they carry a list name argument.